@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -72,6 +72,8 @@ class CTemplate extends CHostGeneral {
 			'editable'					=> false,
 			'nopermissions'				=> null,
 			// filter
+			'evaltype'					=> TAG_EVAL_TYPE_AND_OR,
+			'tags'						=> null,
 			'filter'					=> null,
 			'search'					=> '',
 			'searchByAny'				=> null,
@@ -92,6 +94,7 @@ class CTemplate extends CHostGeneral {
 			'selectMacros'				=> null,
 			'selectScreens'				=> null,
 			'selectHttpTests'			=> null,
+			'selectTags'				=> null,
 			'countOutput'				=> false,
 			'groupCount'				=> false,
 			'preservekeys'				=> false,
@@ -236,6 +239,13 @@ class CTemplate extends CHostGeneral {
 			$sqlParts['where'][] = 'EXISTS (SELECT ht.httptestid FROM httptest ht WHERE ht.hostid=h.hostid)';
 		}
 
+		// tags
+		if ($options['tags'] !== null && $options['tags']) {
+			$sqlParts['where'][] = CApiTagHelper::addWhereCondition($options['tags'], $options['evaltype'], 'h',
+				'host_tag', 'hostid'
+			);
+		}
+
 		// filter
 		if (is_array($options['filter'])) {
 			$this->dbFilter('hosts h', $options, $sqlParts);
@@ -253,7 +263,7 @@ class CTemplate extends CHostGeneral {
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$res = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
+		$res = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($template = DBfetch($res)) {
 			if ($options['countOutput']) {
 				if ($options['groupCount']) {
@@ -300,97 +310,81 @@ class CTemplate extends CHostGeneral {
 
 		$this->validateCreate($templates);
 
-		$ins_templates = [];
+		$templateIds = [];
 
-		foreach ($templates as &$template) {
-			// If visible name is not given or empty it should be set to host name.
-			if (!array_key_exists('name', $template) || trim($template['name']) === '') {
+		foreach ($templates as $key => $template) {
+			$templates[$key]['groups'] = zbx_toArray($template['groups']);
+		}
+
+		$ins_tags = [];
+		foreach ($templates as $template) {
+			// if visible name is not given or empty it should be set to host name
+			if ((!isset($template['name']) || zbx_empty(trim($template['name']))) && isset($template['host'])) {
 				$template['name'] = $template['host'];
 			}
 
-			$ins_templates[] = array_intersect_key($template, array_flip(['host', 'name', 'description'])) +
-				['status' => HOST_STATUS_TEMPLATE];
-		}
-		unset($template);
+			$newTemplateIds = DB::insert('hosts', [[
+				'host' => $template['host'],
+				'name' => $template['name'],
+				'description' => isset($template['description']) ? $template['description'] : null,
+				'status' => HOST_STATUS_TEMPLATE
+			]]);
 
-		$hosts_groups = [];
-		$hosts_macros = [];
-		$templates_hostids = [];
-		$hostids = [];
+			$templateId = reset($newTemplateIds);
 
-		$templateids = DB::insert('hosts', $ins_templates);
+			$templateIds[] = $templateId;
 
-		foreach ($templates as $index => &$template) {
-			$template['templateid'] = $templateids[$index];
-
-			foreach (zbx_toArray($template['groups']) as $group) {
-				$hosts_groups[] = [
-					'hostid' => $template['templateid'],
-					'groupid' => $group['groupid']
-				];
-			}
-
-			if (array_key_exists('macros', $template)) {
-				foreach (zbx_toArray($template['macros']) as $macro) {
-					$hosts_macros[] = ['hostid' => $template['templateid']] + $macro;
+			if (array_key_exists('tags', $template)) {
+				foreach ($template['tags'] as $tag) {
+					$ins_tags[] = ['hostid' => $templateId] + $tag;
 				}
 			}
 
-			if (array_key_exists('templates', $template)) {
-				foreach (zbx_toArray($template['templates']) as $link_template) {
-					$templates_hostids[$link_template['templateid']][] = $template['templateid'];
+			foreach ($template['groups'] as $group) {
+				$hostGroupId = get_dbid('hosts_groups', 'hostgroupid');
+
+				$result = DBexecute(
+					'INSERT INTO hosts_groups (hostgroupid,hostid,groupid)'.
+					' VALUES ('.zbx_dbstr($hostGroupId).','.zbx_dbstr($templateId).','.zbx_dbstr($group['groupid']).')'
+				);
+
+				if (!$result) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot add group.'));
 				}
 			}
 
-			if (array_key_exists('hosts', $template)) {
-				foreach (zbx_toArray($template['hosts']) as $host) {
-					$templates_hostids[$template['templateid']][] = $host['hostid'];
-					$hostids[$host['hostid']] = true;
-				}
+			$template['templateid'] = $templateId;
+
+			$result = $this->massAdd([
+				'templates' => $template,
+				'templates_link' => isset($template['templates']) ? $template['templates'] : null,
+				'macros' => isset($template['macros']) ? $template['macros'] : null,
+				'hosts' => isset($template['hosts']) ? $template['hosts'] : null
+			]);
+
+			if (!$result) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot create template.'));
 			}
 		}
-		unset($template);
 
-		DB::insertBatch('hosts_groups', $hosts_groups);
-
-		if ($hosts_macros) {
-			API::UserMacro()->create($hosts_macros);
+		if ($ins_tags) {
+			DB::insert('host_tag', $ins_tags);
 		}
 
-		if ($hostids) {
-			$this->checkHostPermissions(array_keys($hostids));
-		}
-
-		while ($templates_hostids) {
-			$templateid = key($templates_hostids);
-			$link_hostids = reset($templates_hostids);
-			$link_templateids = [$templateid];
-			unset($templates_hostids[$templateid]);
-
-			foreach ($templates_hostids as $templateid => $hostids) {
-				if ($link_hostids === $hostids) {
-					$link_templateids[] = $templateid;
-					unset($templates_hostids[$templateid]);
-				}
-			}
-
-			$this->link($link_templateids, $link_hostids);
-		}
-
-		$this->addAuditBulk(AUDIT_ACTION_ADD, AUDIT_RESOURCE_TEMPLATE, $templates);
-
-		return ['templateids' => zbx_objectValues($templates, 'templateid')];
+		return ['templateids' => $templateIds];
 	}
 
 	/**
 	 * Validate create template.
 	 *
 	 * @param array $templates
+	 *
+	 * @throws APIException if the input is invalid.
 	 */
 	protected function validateCreate(array $templates) {
 		$groupIds = [];
 
-		foreach ($templates as &$template) {
+		foreach ($templates as $template) {
 			// check if hosts have at least 1 group
 			if (!isset($template['groups']) || !$template['groups']) {
 				self::exception(ZBX_API_ERROR_PARAMETERS,
@@ -401,18 +395,9 @@ class CTemplate extends CHostGeneral {
 			$template['groups'] = zbx_toArray($template['groups']);
 
 			foreach ($template['groups'] as $group) {
-				if (!is_array($group) || (is_array($group) && !array_key_exists('groupid', $group))) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_s('Incorrect value for field "%1$s": %2$s.', 'groups',
-							_s('the parameter "%1$s" is missing', 'groupid')
-						)
-					);
-				}
-
 				$groupIds[$group['groupid']] = $group['groupid'];
 			}
 		}
-		unset($template);
 
 		$dbHostGroups = API::HostGroup()->get([
 			'output' => ['groupid'],
@@ -501,6 +486,11 @@ class CTemplate extends CHostGeneral {
 					));
 				}
 			}
+
+			// Validate tags.
+			if (array_key_exists('tags', $template)) {
+				$this->validateTags($template);
+			}
 		}
 	}
 
@@ -519,7 +509,7 @@ class CTemplate extends CHostGeneral {
 		$macros = [];
 		foreach ($templates as &$template) {
 			if (isset($template['macros'])) {
-				$macros[$template['templateid']] = zbx_toArray($template['macros']);
+				$macros[$template['templateid']] = $template['macros'];
 
 				unset($template['macros']);
 			}
@@ -548,6 +538,8 @@ class CTemplate extends CHostGeneral {
 			}
 		}
 
+		$this->updateTags($templates, 'templateid');
+
 		return ['templateids' => zbx_objectValues($templates, 'templateid')];
 	}
 
@@ -555,6 +547,8 @@ class CTemplate extends CHostGeneral {
 	 * Validate update template.
 	 *
 	 * @param array $templates
+	 *
+	 * @throws APIException if the input is invalid.
 	 */
 	protected function validateUpdate(array $templates) {
 		$dbTemplates = $this->get([
@@ -573,6 +567,11 @@ class CTemplate extends CHostGeneral {
 			if (array_key_exists('auto_compress', $template)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
 			}
+
+			// Validate tags.
+			if (array_key_exists('tags', $template)) {
+				$this->validateTags($template);
+			}
 		}
 	}
 
@@ -589,15 +588,17 @@ class CTemplate extends CHostGeneral {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
 		}
 
-		$db_templates = $this->get([
-			'output' => ['templateid', 'host', 'name'],
+		$options = [
 			'templateids' => $templateids,
 			'editable' => true,
+			'output' => API_OUTPUT_EXTEND,
 			'preservekeys' => true
-		]);
-
-		if (array_diff_key(array_flip($templateids), $db_templates)) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('You do not have permission to perform this operation.'));
+		];
+		$delTemplates = $this->get($options);
+		foreach ($templateids as $templateid) {
+			if (!isset($delTemplates[$templateid])) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS, _('You do not have permission to perform this operation.'));
+			}
 		}
 
 		API::Template()->unlink($templateids, null, true);
@@ -675,7 +676,7 @@ class CTemplate extends CHostGeneral {
 		}
 
 		DB::delete('optemplate', [
-			'templateid'=>$templateids
+			'templateid'=>$templateids,
 		]);
 
 		// delete empty operations
@@ -690,7 +691,7 @@ class CTemplate extends CHostGeneral {
 		}
 
 		DB::delete('operations', [
-			'operationid'=>$delOperationids
+			'operationid'=>$delOperationids,
 		]);
 
 		// http tests
@@ -718,15 +719,51 @@ class CTemplate extends CHostGeneral {
 		DB::delete('hosts', ['hostid' => $templateids]);
 
 		// TODO: remove info from API
-		foreach ($db_templates as $db_template) {
-			info(_s('Deleted: Template "%1$s".', $db_template['name']));
+		foreach ($delTemplates as $template) {
+			info(_s('Deleted: Template "%1$s".', $template['name']));
+			add_audit_ext(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_HOST, $template['templateid'], $template['host'], 'hosts', null, null);
 		}
 
-		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_TEMPLATE, $db_templates);
-
 		return ['templateids' => $templateids];
 	}
 
+	/**
+	 * Checks if the current user has access to the given hosts and templates. Assumes the "hostid" field is valid.
+	 *
+	 * @param array $hostids    an array of host or template IDs
+	 *
+	 * @throws APIException if the user doesn't have write permissions for the given hosts.
+	 *
+	 * @return void
+	 */
+	protected function checkHostPermissions(array $hostids) {
+		if ($hostids) {
+			$hostids = array_unique($hostids);
+
+			$count = API::Host()->get([
+				'countOutput' => true,
+				'hostids' => $hostids,
+				'editable' => true
+			]);
+
+			if ($count == count($hostids)) {
+				return;
+			}
+
+			$count += $this->get([
+				'countOutput' => true,
+				'templateids' => $hostids,
+				'editable' => true
+			]);
+
+			if ($count != count($hostids)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
+		}
+	}
+
 	/**
 	 * Additionally allows to link templates to hosts and other templates.
 	 *
@@ -1131,21 +1168,15 @@ class CTemplate extends CHostGeneral {
 		// Adding Templates
 		if ($options['selectTemplates'] !== null) {
 			if ($options['selectTemplates'] != API_OUTPUT_COUNT) {
-				$templates = [];
 				$relationMap = $this->createRelationMap($result, 'templateid', 'hostid', 'hosts_templates');
-				$related_ids = $relationMap->getRelatedIds();
-
-				if ($related_ids) {
-					$templates = API::Template()->get([
-						'output' => $options['selectTemplates'],
-						'templateids' => $related_ids,
-						'preservekeys' => true
-					]);
-					if (!is_null($options['limitSelects'])) {
-						order_result($templates, 'host');
-					}
+				$templates = API::Template()->get([
+					'output' => $options['selectTemplates'],
+					'templateids' => $relationMap->getRelatedIds(),
+					'preservekeys' => true
+				]);
+				if (!is_null($options['limitSelects'])) {
+					order_result($templates, 'host');
 				}
-
 				$result = $relationMap->mapMany($result, $templates, 'templates', $options['limitSelects']);
 			}
 			else {
@@ -1166,21 +1197,15 @@ class CTemplate extends CHostGeneral {
 		// Adding Hosts
 		if ($options['selectHosts'] !== null) {
 			if ($options['selectHosts'] != API_OUTPUT_COUNT) {
-				$hosts = [];
 				$relationMap = $this->createRelationMap($result, 'templateid', 'hostid', 'hosts_templates');
-				$related_ids = $relationMap->getRelatedIds();
-
-				if ($related_ids) {
-					$hosts = API::Host()->get([
-						'output' => $options['selectHosts'],
-						'hostids' => $related_ids,
-						'preservekeys' => true
-					]);
-					if (!is_null($options['limitSelects'])) {
-						order_result($hosts, 'host');
-					}
+				$hosts = API::Host()->get([
+					'output' => $options['selectHosts'],
+					'hostids' => $relationMap->getRelatedIds(),
+					'preservekeys' => true
+				]);
+				if (!is_null($options['limitSelects'])) {
+					order_result($hosts, 'host');
 				}
-
 				$result = $relationMap->mapMany($result, $hosts, 'hosts', $options['limitSelects']);
 			}
 			else {
