@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ function get_cookie($name, $default_value = null) {
 }
 
 function zbx_setcookie($name, $value, $time = null) {
-	setcookie($name, $value, isset($time) ? $time : 0, null, null, HTTPS, true);
+	setcookie($name, $value, isset($time) ? $time : 0, CSession::getDefaultCookiePath(), null, HTTPS, true);
 	$_COOKIE[$name] = $value;
 }
 
@@ -294,7 +294,7 @@ function zbx_date2str($format, $value = null) {
 }
 
 /**
- * Calculates and converts timestamp to string represenation.
+ * Calculates and converts timestamp to string representation.
  *
  * @param int|string $start_date  Start date timestamp.
  * @param int|string $end_date    End date timestamp.
@@ -998,7 +998,7 @@ function zbx_is_int($var) {
 
 /**
  * Look for two arrays field value and create 3 array lists, one with arrays where field value exists only in first array
- * second with arrays where field values are only in second array and both where fiel values are in both arrays.
+ * second with arrays where field values are only in second array and both where field values are in both arrays.
  *
  * @param array  $primary
  * @param array  $secondary
@@ -1348,7 +1348,7 @@ function zbx_toObject($value, $field, $preserve_keys = false) {
  * Converts the given value to a numeric array:
  * - a scalar value will be converted to an array and added as the only element;
  * - an array with first element key containing only numeric characters will be converted to plain zero-based numeric array.
- * This is used for reseting nonsequential numeric arrays;
+ * This is used for resetting nonsequential numeric arrays;
  * - an associative array will be returned in an array as the only element, except if first element key contains only numeric characters.
  *
  * @param mixed $value
@@ -1442,26 +1442,6 @@ function zbx_toCSV($values) {
 	return $csv;
 }
 
-function zbx_array_mintersect($keys, $array) {
-	$result = [];
-
-	foreach ($keys as $field) {
-		if (is_array($field)) {
-			foreach ($field as $sub_field) {
-				if (isset($array[$sub_field])) {
-					$result[$sub_field] = $array[$sub_field];
-					break;
-				}
-			}
-		}
-		elseif (isset($array[$field])) {
-			$result[$field] = $array[$field];
-		}
-	}
-
-	return $result;
-}
-
 function zbx_str2links($text) {
 	$result = [];
 
@@ -2013,15 +1993,6 @@ function show_messages($good = false, $okmsg = null, $errmsg = null) {
 				];
 			}
 			break;
-		case PAGE_TYPE_XML:
-			if ($title !== null) {
-				echo htmlspecialchars($title)."\n";
-			}
-
-			foreach ($messages as $message) {
-				echo '['.$message['type'].'] '.$message['message']."\n";
-			}
-			break;
 		case PAGE_TYPE_HTML:
 		default:
 			if ($title || $messages) {
