@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -424,4 +424,8 @@
 #	include <stddef.h>
 #endif
 
+#ifdef HAVE_LIMITS_H
+#	include <limits.h>
+#endif
+
 #endif
