@@ -24,13 +24,17 @@
 #define ZBX_STR(str)	ZBX_STR2(str)
 
 #define APPLICATION_NAME	"Zabbix Agent"
-#define ZABBIX_REVDATE		"21 February 2020"
+#define ZABBIX_REVDATE		"23 March 2020"
 #define ZABBIX_VERSION_MAJOR	4
 #define ZABBIX_VERSION_MINOR	4
-#define ZABBIX_VERSION_PATCH	6
-#define ZABBIX_VERSION_REVISION	8cc702429d
+#define ZABBIX_VERSION_PATCH	7
+#ifndef ZABBIX_VERSION_REVISION
+#	define ZABBIX_VERSION_REVISION	77fb8c7ee0
+#endif
 #ifdef _WINDOWS
-#	define ZABBIX_VERSION_RC_NUM	1400
+#	ifndef ZABBIX_VERSION_RC_NUM
+#		define ZABBIX_VERSION_RC_NUM	1400
+#	endif
 #endif
 #define ZABBIX_VERSION_RC	""
 #define ZABBIX_VERSION		ZBX_STR(ZABBIX_VERSION_MAJOR) "." ZBX_STR(ZABBIX_VERSION_MINOR) "." \
