@@ -185,6 +185,14 @@ func main() {
 	flag.BoolVar(&printFlag, "print", printDefault, printDescription)
 	flag.BoolVar(&printFlag, "p", printDefault, printDescription+" (shorthand)")
 
+	var verboseFlag bool
+	const (
+		verboseDefault     = false
+		verboseDescription = "Enable verbose output for metric testing or printing"
+	)
+	flag.BoolVar(&verboseFlag, "verbose", verboseDefault, verboseDescription)
+	flag.BoolVar(&verboseFlag, "v", verboseDefault, verboseDescription+" (shorthand)")
+
 	var versionFlag bool
 	const (
 		versionDefault     = false
@@ -202,7 +210,7 @@ func main() {
 
 	flag.Parse()
 
-	var argConfig, argTest, argPrint, argVersion bool
+	var argConfig, argTest, argPrint, argVersion, argVerbose bool
 
 	// Need to manually check if the flag was specified, as default flag package
 	// does not offer automatic detection. Consider using third party package.
@@ -216,6 +224,8 @@ func main() {
 			argPrint = true
 		case "V", "version":
 			argVersion = true
+		case "v", "verbose":
+			argVerbose = true
 		}
 	})
 
@@ -239,21 +249,38 @@ func main() {
 	}
 
 	if argTest || argPrint {
-		if err := log.Open(log.Console, log.Warning, "", 0); err != nil {
+		var level int
+		if argVerbose {
+			level = log.Trace
+		} else {
+			level = log.Empty
+		}
+		if err := log.Open(log.Console, level, "", 0); err != nil {
 			fatalExit("cannot initialize logger", err)
 		}
 
+		var m *scheduler.Manager
+		var err error
+		if m, err = scheduler.NewManager(&agent.Options); err != nil {
+			fatalExit("cannot create scheduling manager", err)
+		}
+		m.Start()
+
 		if argTest {
-			if err := agent.CheckMetric(testFlag); err != nil {
-				fatalExit("cannot execute metric", err)
-			}
+			checkMetric(m, testFlag)
 		} else {
-			agent.CheckMetrics()
+			checkMetrics(m)
 		}
 
+		m.Stop()
+		monitor.Wait(monitor.Scheduler)
 		os.Exit(0)
 	}
 
+	if argVerbose {
+		fatalExit("", errors.New("verbose parameter can be specified only with test or print parameters"))
+	}
+
 	if remoteCommand != "" {
 		if agent.Options.ControlSocket == "" {
 			fmt.Fprintf(os.Stderr, "Cannot send remote command: ControlSocket configuration parameter is not defined\n")
@@ -385,16 +412,24 @@ func main() {
 	if agent.Options.StatusPort != 0 {
 		statuslistener.Stop()
 	}
-
 	for _, listener := range listeners {
 		listener.Stop()
 	}
 	for i := 0; i < len(serverConnectors); i++ {
-		serverConnectors[i].Stop()
+		serverConnectors[i].StopConnector()
 	}
-	manager.Stop()
+	monitor.Wait(monitor.Input)
 
-	monitor.Wait()
+	manager.Stop()
+	monitor.Wait(monitor.Scheduler)
+
+	// split shutdown in two steps to ensure that result cache is still running while manager is
+	// being stopped, because there might be pending exporters that could block if result cache
+	// is stoppped and its input channel is full.
+	for i := 0; i < len(serverConnectors); i++ {
+		serverConnectors[i].StopCache()
+	}
+	monitor.Wait(monitor.Output)
 
 	farewell := fmt.Sprintf("Zabbix Agent 2 stopped. (%s)", version.Long())
 	log.Infof(farewell)
@@ -406,7 +441,7 @@ func main() {
 
 func fatalExit(message string, err error) {
 	if len(message) == 0 {
-		message = fmt.Sprintf("%s", err.Error())
+		message = err.Error()
 	} else {
 		message = fmt.Sprintf("%s: %s", message, err.Error())
 	}
