@@ -33,26 +33,42 @@ import (
 	"zabbix.com/pkg/zbxlib"
 )
 
+// clientItem represents item monitored by client
 type clientItem struct {
 	itemid uint64
 	delay  string
 	key    string
 }
 
+// pluginInfo is used to track plugin usage by client
 type pluginInfo struct {
-	used    time.Time
+	used time.Time
+	// temporary link to a watcherTask during update
 	watcher *watcherTask
 }
 
+// client represents source of items (metrics) to be queried.
+// Each server for active checks is represented by a separate client.
+// There is a predefined clients to handle:
+//    all single passive checks (client id 1)
+//    all internal checks (resolving HostnameItem, HostMetadataItem, HostInterfaceItem) (client id 0)
 type client struct {
-	id                 uint64
-	exporters          map[uint64]exporterTaskAccessor
-	pluginsInfo        map[*pluginAgent]*pluginInfo
+	// Client id. Predefined clients have ids < 100, while clients active checks servers (ServerActive)
+	// have auto incrementing id starting with 100.
+	id uint64
+	// A map of itemids to the associated exporter tasks. It's used to update task when item parameters change.
+	exporters map[uint64]exporterTaskAccessor
+	// plugins used by client
+	pluginsInfo map[*pluginAgent]*pluginInfo
+	// server refresh unsupported value
 	refreshUnsupported int
-	globalRegexp       unsafe.Pointer
-	output             plugin.ResultWriter
+	// server global regular expression bundle
+	globalRegexp unsafe.Pointer
+	// plugin result sink, can be nil for bulk passive checks (in future)
+	output plugin.ResultWriter
 }
 
+// ClientAccessor interface exports client data required for scheduler tasks.
 type ClientAccessor interface {
 	RefreshUnsupported() int
 	Output() plugin.ResultWriter
@@ -60,31 +76,37 @@ type ClientAccessor interface {
 	ID() uint64
 }
 
-// RefreshUnsupported is used only by scheduler, no synchronization is required
+// RefreshUnsupported returns scheduling interval for unsupported items.
+// This function is used only by scheduler, no synchronization is required.
 func (c *client) RefreshUnsupported() int {
 	return c.refreshUnsupported
 }
 
-// GlobalRegexp() is used by tasks to implement ContextProvider interface.
-// In theory it can be accessed by plugins and replaced by scheduler at the same time,
+// GlobalRegexp returns global regular expression bundle.
+// This function is used by tasks to implement ContextProvider interface.
+// It can be accessed by plugins and replaced by scheduler at the same time,
 // so pointer access must be synchronized. The global regexp contents are never changed,
 // only replaced, so pointer synchronization is enough.
 func (c *client) GlobalRegexp() *glexpr.Bundle {
 	return (*glexpr.Bundle)(atomic.LoadPointer(&c.globalRegexp))
 }
 
-// While ID() is used by tasks to implement ContextProvider interface, client ID cannot
+// ID returns client id.
+// While it's used by tasks to implement ContextProvider interface, client ID cannot
 // change, so no synchronization is required.
 func (c *client) ID() uint64 {
 	return c.id
 }
 
-// While Output() is used by tasks to implement ContextProvider interface, client output cannot
+// Output returns client ouput interface where plugins results can be written.
+// While it's used by tasks to implement ContextProvider interface, client output cannot
 // change, so no synchronization is required.
 func (c *client) Output() plugin.ResultWriter {
 	return c.output
 }
 
+// addRequest requests client to start monitoring/update item described by request 'r' using plugin 'p' (*pluginAgent)
+// with output writer 'sink'
 func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.ResultWriter, now time.Time) (err error) {
 	var info *pluginInfo
 	var ok bool
@@ -95,11 +117,13 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 		info = &pluginInfo{}
 	}
 
+	// list of created tasks to be queued
 	tasks := make([]performer, 0, 6)
 
 	// handle Collector interface
 	if col, ok := p.impl.(plugin.Collector); ok {
 		if p.refcount == 0 {
+			// calculate collector seed to avoid scheduling all collectors at the same time
 			h := fnv.New32a()
 			_, _ = h.Write([]byte(p.impl.Name()))
 			task := &collectorTask{
@@ -117,8 +141,8 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 	// handle Exporter interface
 	if _, ok := p.impl.(plugin.Exporter); ok {
 		var tacc exporterTaskAccessor
-
 		if c.id != 0 {
+			// handle active checks exporter request
 			var task *exporterTask
 			if _, err = zbxlib.GetNextcheck(r.Itemid, r.Delay, now, false, c.refreshUnsupported); err != nil {
 				return err
@@ -129,13 +153,15 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 					return errors.New("duplicate itemid found")
 				}
 				if task.plugin != p {
-					// create new task if item key has been changed and now is handled by other plugin
+					// decativate current exporter task and create new one if the item key has been changed
+					// and the new metric is handled by other plugin
 					task.deactivate()
 					ok = false
 				}
 			}
 
 			if !ok {
+				// create and register new exporter task
 				task = &exporterTask{
 					taskBase: taskBase{plugin: p, active: true, recurring: true},
 					item:     clientItem{itemid: r.Itemid, delay: r.Delay, key: r.Key},
@@ -151,6 +177,7 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 				log.Debugf("[%d] created exporter task for plugin '%s' itemid:%d key '%s'",
 					c.id, p.name(), task.item.itemid, task.item.key)
 			} else {
+				// update existing exporter task
 				task = tacc.task()
 				task.updated = now
 				task.item.key = r.Key
@@ -168,6 +195,7 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 			task.meta.SetMtime(int32(*r.Mtime))
 
 		} else {
+			// handle single passive check or internal request
 			task := &directExporterTask{
 				taskBase: taskBase{plugin: p, active: true, recurring: true},
 				item:     clientItem{itemid: r.Itemid, delay: r.Delay, key: r.Key},
@@ -175,7 +203,6 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 				client:   c,
 				output:   sink,
 			}
-			// cache scheduled (non direct) request tasks
 			if err = task.reschedule(now); err != nil {
 				return
 			}
@@ -199,25 +226,22 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 		}
 	}
 
-	// Watcher plugins are not supported by direct requests
-	if c.id != 0 {
-		// handle Watcher interface
-		if _, ok := p.impl.(plugin.Watcher); ok {
-			if info.watcher == nil {
-				info.watcher = &watcherTask{
-					taskBase: taskBase{plugin: p, active: true},
-					requests: make([]*plugin.Request, 0, 1),
-					client:   c,
-				}
-				if err = info.watcher.reschedule(now); err != nil {
-					return
-				}
-				tasks = append(tasks, info.watcher)
-
-				log.Debugf("[%d] created watcher task for plugin %s", c.id, p.name())
+	// handle Watcher interface (not supported by single passive check or internal requests)
+	if _, ok := p.impl.(plugin.Watcher); ok && c.id != 0 {
+		if info.watcher == nil {
+			info.watcher = &watcherTask{
+				taskBase: taskBase{plugin: p, active: true},
+				requests: make([]*plugin.Request, 0, 1),
+				client:   c,
 			}
-			info.watcher.requests = append(info.watcher.requests, r)
+			if err = info.watcher.reschedule(now); err != nil {
+				return
+			}
+			tasks = append(tasks, info.watcher)
+
+			log.Debugf("[%d] created watcher task for plugin %s", c.id, p.name())
 		}
+		info.watcher.requests = append(info.watcher.requests, r)
 	}
 
 	// handle configurator interface for inactive plugins
@@ -232,10 +256,12 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 			log.Debugf("[%d] created configurator task for plugin %s", c.id, p.name())
 		}
 	}
+
 	for _, t := range tasks {
 		p.enqueueTask(t)
 	}
 
+	// update plugin usage information
 	if info.used.IsZero() {
 		p.refcount++
 		c.pluginsInfo[p] = info
@@ -245,14 +271,16 @@ func (c *client) addRequest(p *pluginAgent, r *plugin.Request, sink plugin.Resul
 	return nil
 }
 
+// cleanup releases unused uplugins. For external clients it's done after update,
+// while for internal clients once per hour.
 func (c *client) cleanup(plugins map[string]*pluginAgent, now time.Time) (released []*pluginAgent) {
 	released = make([]*pluginAgent, 0, len(c.pluginsInfo))
-	// remover references to temporary watcher tasks
+	// remove reference to temporary watcher tasks
 	for _, p := range c.pluginsInfo {
 		p.watcher = nil
 	}
 
-	// remove unused items
+	// unmap not monitored exporter tasks
 	for _, tacc := range c.exporters {
 		task := tacc.task()
 		if task.updated.Before(now) {
@@ -262,10 +290,10 @@ func (c *client) cleanup(plugins map[string]*pluginAgent, now time.Time) (releas
 		}
 	}
 
-	var expiry time.Time
 	// Direct requests are handled by special client with id 0. Such requests have
 	// day+hour (to keep once per day checks without expiring) expiry time before
 	// used plugins are released.
+	var expiry time.Time
 	if c.id != 0 {
 		expiry = now
 	} else {
@@ -276,29 +304,28 @@ func (c *client) cleanup(plugins map[string]*pluginAgent, now time.Time) (releas
 	for _, p := range plugins {
 		if info, ok := c.pluginsInfo[p]; ok {
 			if info.used.Before(expiry) {
-				// perform empty watch task before closing
-				if c.id != 0 {
-					if _, ok := p.impl.(plugin.Watcher); ok {
-						task := &watcherTask{
-							taskBase: taskBase{plugin: p, active: true},
-							requests: make([]*plugin.Request, 0),
-							client:   c,
-						}
-						if err := task.reschedule(now); err == nil {
-							p.enqueueTask(task)
-							log.Debugf("[%d] created watcher task for plugin %s", c.id, p.name())
-						} else {
-							// currently watcher rescheduling cannot fail, but log a warning for future
-							log.Warningf("[%d] cannot reschedule plugin '%s' closing watcher task: %s",
-								c.id, p.impl.Name(), err)
-						}
+				// perform empty watch task before releasing plugin, so it could
+				// release internal resources allocated to monitor this client
+				if _, ok := p.impl.(plugin.Watcher); ok && c.id != 0 {
+					task := &watcherTask{
+						taskBase: taskBase{plugin: p, active: true},
+						requests: make([]*plugin.Request, 0),
+						client:   c,
+					}
+					if err := task.reschedule(now); err == nil {
+						p.enqueueTask(task)
+						log.Debugf("[%d] created watcher task for plugin %s", c.id, p.name())
+					} else {
+						// currently watcher rescheduling cannot fail, but log a warning for future
+						log.Warningf("[%d] cannot reschedule plugin '%s' closing watcher task: %s",
+							c.id, p.impl.Name(), err)
 					}
 				}
 
+				// release plugin
 				released = append(released, p)
 				delete(c.pluginsInfo, p)
 				p.refcount--
-				// TODO: define uniform time format
 				if c.id != 0 {
 					log.Debugf("[%d] released unused plugin %s", c.id, p.name())
 				} else {
@@ -311,6 +338,7 @@ func (c *client) cleanup(plugins map[string]*pluginAgent, now time.Time) (releas
 	return
 }
 
+// updateExpressions updates server global regular expression bundle
 func (c *client) updateExpressions(expressions []*glexpr.Expression) {
 	// reset expressions if changed
 	glexpr.SortExpressions(expressions)
@@ -328,6 +356,7 @@ func (c *client) updateExpressions(expressions []*glexpr.Expression) {
 	}
 }
 
+// newClient creates new client
 func newClient(id uint64, output plugin.ResultWriter) (b *client) {
 	b = &client{
 		id:          id,
