@@ -26,7 +26,7 @@ import (
 	_ "zabbix.com/plugins/net/tcp"
 	_ "zabbix.com/plugins/proc"
 	_ "zabbix.com/plugins/redis"
-	_ "zabbix.com/plugins/system/cpucollector"
+	_ "zabbix.com/plugins/system/cpu"
 	_ "zabbix.com/plugins/system/uname"
 	_ "zabbix.com/plugins/system/uptime"
 	_ "zabbix.com/plugins/systemd"
